@@ -170,12 +170,13 @@ def get_domain_ip(domain):
 
 
 
-def get_user_link(uuid,domain):
+def get_user_link(uuid,domain,mode=''):
         proxy_path=hconfig(ConfigEnum.proxy_path)
-        text=domain.domain
+        text= _('all') if mode else domain.domain
         if domain.mode==DomainType.cdn:
             text=f'<span class="badge badge-success" >{_("domain.cdn")}</span>'+text        
-        return f"<a target='_blank' href='https://{domain.domain}/{proxy_path}/{uuid}/'><span class='badge badge-info ltr'>{text}</span></a>"
+        
+        return f"<a target='_blank' href='https://{domain.domain}/{proxy_path}/{uuid}/{mode}'><span class='badge badge-info ltr'>{text}</span></a>"
 
 
 
